/*************************************************** 
  This is a library for our I2C LED Backpacks

  Designed specifically to work with the Adafruit LED 7-Segment backpacks 
  ----> http://www.adafruit.com/products/881
  ----> http://www.adafruit.com/products/880
  ----> http://www.adafruit.com/products/879
  ----> http://www.adafruit.com/products/878

  These displays use I2C to communicate, 2 pins are required to 
  interface. There are multiple selectable I2C addresses. For backpacks
  with 2 Address Select pins: 0x70, 0x71, 0x72 or 0x73. For backpacks
  with 3 Address Select pins: 0x70 thru 0x77

  Adafruit invests time and resources providing this open source code, 
  please support Adafruit and open-source hardware by purchasing 
  products from Adafruit!

  Written by Limor Fried/Ladyada for Adafruit Industries.  
  BSD license, all text above must be included in any redistribution
 ****************************************************/

// Enable one of these two #includes and comment out the other.
// Conditional #include doesn't work due to Arduino IDE shenanigans.
#include <Wire.h> // Enable this line if using Arduino Uno, Mega, etc.
//#include <TinyWireM.h> // Enable this line if using Adafruit Trinket, Gemma, etc.

#include "Adafruit_LEDBackpack.h"
#include "Adafruit_GFX.h"

Adafruit_7segment matrix = Adafruit_7segment();

void setup() {
#ifndef __AVR_ATtiny85__
  Serial.begin(9600);
  Serial.println("DS3231 Projector Clock Test");
#endif
  
  // clear /EOSC bit
  // Sometimes necessary to ensure that the clock
  // keeps running on just battery power. Once set,
  // it shouldn't need to be reset but it's a good
  // idea to make sure.
  matrix.begin(0x70);
  
  Wire.beginTransmission(0x68); // address DS3231
  Wire.write(0x0E); // select register
  Wire.write(0b00011100); // write register bitmap, bit 7 is /EOSC
  Wire.endTransmission();

}

void loop() {
  int seconds;
  int minutes;
  int hours;
  int temph;
  int templ;
  boolean drawDots;

// send request to receive data starting at register 0
  Wire.beginTransmission(0x68); // 0x68 is DS3231 device address
  Wire.write((byte)0); // start at register 0
  Wire.endTransmission();
  Wire.requestFrom(0x68, 3); // request three bytes (seconds, minutes, hours)
  
  while(Wire.available())
  { 
    seconds = Wire.read(); // get seconds
    minutes = Wire.read(); // get minutes
    hours = Wire.read();   // get hour
  }
    
// send request to receive data starting at register 11
  Wire.beginTransmission(0x68); // 0x68 is DS3231 device address
  Wire.write(0x11); // start at register 0
  Wire.endTransmission();
  Wire.requestFrom(0x68, 2); // request two bytes (MSB & LSB temp) 
    
  while(Wire.available())
  { 
    temph = Wire.read(); // get MSB temp
    templ = Wire.read(); // get LSB temp 
  }

    seconds = (((seconds & 0b11110000)>>4)*10 + (seconds & 0b00001111)); // convert BCD to decimal
    minutes = (((minutes & 0b11110000)>>4)*10 + (minutes & 0b00001111)); // convert BCD to decimal
    hours = (((hours & 0b00100000)>>5)*20 + ((hours & 0b00010000)>>4)*10 + (hours & 0b00001111)); // convert BCD to decimal (assume 24 hour mode)
    templ = templ >> 6; //get 2 msb
    templ = (templ * 25) / 10; //0,25C pr bit
  
  if ((hours > 8) and (hours < 20)) {
	  matrix.setBrightness(0);
	 } else {
	  matrix.setBrightness(15);
	 }

  if (seconds % 2) {
    drawDots = true;
  } else {
    drawDots = false;
  }

   
// method #2 - draw each digit
  if ((seconds < 10) or ((seconds > 19) and (seconds < 30)) or ((seconds > 39) and (seconds < 50)))
  {
    matrix.writeDigitNum(0, (hours / 10) % 10, 0);
    matrix.writeDigitNum(1, (hours) % 10, 0);
    matrix.drawColon(drawDots);
    matrix.writeDigitNum(3, (minutes / 10) % 10, 0);
    matrix.writeDigitNum(4, minutes % 10, 0); 
  } else {
    matrix.print(0x000C, HEX);
    matrix.writeDigitNum(0, (temph / 10) % 10, 0);
    matrix.writeDigitNum(1, (temph) % 10, 0);
    matrix.drawColon(drawDots);
    matrix.writeDigitNum(3, templ, 0);

  } 
    matrix.writeDisplay();
    delay(1000);
    
}
